<!--
 * @Author: elkers
 * @Date: 2024-08-06 16:17:39
 * @LastEditors: hqs elkers@163.com
 * @LastEditTime: 2024-08-13 17:43:00
 * @FilePath: \water-qinghe-web\src\views\waterMeter\waterMeter\index.vue
 * @Description: 水表信息
-->

 <script setup>
 import  waterMeterApi from "@/api/waterMeterApi/index";
 import {onMounted} from "vue";
 import userClassify from "@/api/configuration/userClassify/index.js";
 import  waterModelApi from "@/api/waterMeterApi/waterModel";
 import  setPostParams from "@/utils/searchParams";
 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:searchParams.value.modelCode})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */

const pageParam = ref({
    total:0,
    limit:0,
    page:1,
})
const tableData = ref([]);
let  tableHeader = ref({
        sn: '水表编号',
        modelName:'水表型号',
        initialReading: '初始读数',
        meterTypeView:'水表分类',
        isUseView:'是否使用',
        manufactureTime:'生成日期',
        createTimeView:'创建时间'
   })
const  rules = ref({
    sn: [{ required: true, message: "请输入水表编号", trigger: "blur" }],
    modelId: [{ required: true, message: "请选择水表型号", trigger: "blur" }],
    initialReading: [{ required: true, message: "请输入水表初始读数", trigger: "blur" }],
    manufactureTime: [{ required: true, message: "请选择生产日期", trigger: "blur" }],
    meterType: [{ required: true, message: "请选择水表分类", trigger: "blur" }],
});
const form = ref({});
const searchParams = ref({
    keywords: '',
});
 /** 获取列表 */
 async function getList(val) {
      loading.value = true;
      let postParam = setPostParams(val)
      await waterMeterApi().search(postParam).then((res) =>{
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
 }
 
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
   open.value = true;
   title.value = "新增";
 }
 
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   // form.value = Object.assign({},row)
   Object.keys(row).forEach(key => {  
      if (form.value.hasOwnProperty(key)) {  
         form.value[key] = row[key];  
      }  
   });
   form.value.id = row.id
   open.value = true;
   title.value = "修改";
 }

/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.isUse + '"的数据项?').then(function() {
    return waterMeterApi().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}
 

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const loading = ref(false);
const title = ref("");
const meterTypeList = ref([
     { id: 1, name: '用户水表' },
     { id: 2, name: '大口径水表' }

 ])
const modelList = ref([])

//上传文件，添加图片地址信息
const uploadData = (data) => {
    form.value.headImg = data.newFileView
}
 /** 提交按钮 */
 function submitForm() {
   proxy.$refs["userRef"].validate(valid => {
     if (valid) {
       if (form.value.id != undefined) {
         waterMeterApi().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       } else {
         waterMeterApi().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });;
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 
 /** 表单重置 */
 function reset() {
   form.value = {
        sn: '',
        modelId: undefined,
        initialReading: '',
        meterType: '',
        manufactureTime:'',
        isUse:'',
        remark: '',

   };
   proxy.resetForm("userRef");
 }
 onMounted(async() =>{
     // 获取用户类型
     let res1 = await waterModelApi().search({ status: 1,limit: 10000, page: 1})
     if(res1.code == 200) {
         modelList.value = res1.data.list
     }
 })
 getList();
 </script>
 <template>
    <div class="app-container">
       <el-form :model="searchParams" ref="queryRef" :inline="true">
          <el-form-item label="用户名称" prop="modelCode">
             <el-input
                v-model="searchParams.modelCode"
                placeholder="请输入搜索内容"
                clearable
                style="width: 200px"
                @keyup.enter="handleQuery"
             />
          </el-form-item>
          <el-form-item>
             <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
             <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
       </el-form>
 
       <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
       </el-row>
       <!--表格及分页-->
       <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          >
            <template #default="scope">
                <div v-if="key.toString() == 'headImg'">
                    <img :src="scope.row.headImg" class="table-headImg"/>
                </div>
            </template>
        </el-table-column>
          <el-table-column label="操作" width="180" align="center" class-modelCode="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" v-has="['update',route]" @click="handleUpdate(scope.row)">修改</el-button>
                <el-button link type="primary" icon="Delete" v-has="['delete',route]" @click="handleDelete(scope.row)">删除</el-button>
             </template>
          </el-table-column>
        </el-table>
        <pagination
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          :page-sizes="[10,20,30]"
          @pagination="getList"
        />
       <!-- 添加或修改权限对话框 -->
       <el-dialog :title="title" v-model="open" append-to-body center>
          <el-form class="form-box" ref="userRef" :model="form" :rules="rules" label-width='auto'>
                   <el-form-item label="水表编号" prop="sn">
                      <el-input v-model="form.sn" placeholder="请输入水表编号"/>
                   </el-form-item>
                     <el-form-item label="水表型号"  prop="modelId">
                         <el-select v-model="form.modelId" class="m-2" placeholder="请选择" size="large">
                             <el-option
                                     v-for="item in modelList"
                                     :key="item.id"
                                     :label="item.model"
                                     :title="item.model"
                                     :value="item.id"
                             />
                         </el-select>
                     </el-form-item>
                     <el-form-item label="水表分类"  prop="meterType">
                         <el-select v-model="form.meterType" class="m-2" placeholder="请选择" size="large">
                             <el-option
                                     v-for="item in meterTypeList"
                                     :key="item.id"
                                     :label="item.name"
                                     :title="item.name"
                                     :value="item.id"
                             />
                         </el-select>
                     </el-form-item>
                   <el-form-item label="初始读数" prop="initialReading">
                      <el-input v-model="form.initialReading" placeholder="请输入初始读数" />
                   </el-form-item>
                    <el-form-item label="生产日期" prop="manufactureTime">
                        <el-date-picker
                                v-model="form.manufactureTime"
                                type="date"
                                placeholder="请选择生产日期"
                                format="YYYY-MM-DD"
                                value-format="YYYY-MM-DD"
                                :disabled="isDetail ? true : false"
                        />
                    </el-form-item>
                    <el-form-item label="备注信息" prop="remark">
                        <el-input v-model="form.remark" placeholder="请选择" />
                    </el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
       </el-dialog>
    </div>
 </template>
 
 <style>
 .table-headImg{
    width: 50px;
    height: 50px;
 }
</style>
 